@@ -20,17 +20,37 @@ function StartPedro(editorId) {
 	});
 
 	$("#theme_selector").change(function() {
-		var input = document.getElementById("theme_selector");
-		var theme = input.options[input.selectedIndex].innerHTML;
-		editor.setOption("theme", theme);
+		editor.setOption("theme", $(":selected", this).val());
+	});
+
+	function changeMode(cm, modeFile, mode) {
+		if(typeof mode == 'undefined') {
+			mode = modeFile;
+		}
+		CodeMirror.modeURL = "../js/codemirror/mode/%N.js";
+		cm.setOption("mode", mode);
+		CodeMirror.autoLoadMode(cm, modeFile);	
+	}
+
+	$("#mode_selector").change(function() {
+		var $selectedMode = $(":selected", this);
+		humane.log("Mode changed to " + $selectedMode.html());
+		var mode = $selectedMode.val();
+		if(mode == 'clike') {
+			changeMode(editor, mode, 'text/x-csrc');
+		} else if(mode == 'plsql') {
+			changeMode(editor, mode, 'text/x-plsql');
+		} else {
+			changeMode(editor, mode);
+		}
 	});
 
 	var jsResultEditor = CodeMirror.fromTextArea(document.getElementById("js-result"), {
 		lineNumbers: true,
 		matchBrackets: true,
-		mode: "text/javascript",
 		readOnly: true,
 	});
+	changeMode(jsResultEditor, 'javascript');
 	
 	var editor = CodeMirror.fromTextArea(document.getElementById(editorId), {
 		lineNumbers: true,
@@ -38,7 +58,6 @@ function StartPedro(editorId) {
 		tabSize: 4,
 		indentUnit: 4,
 		indentWithTabs: true,
-		mode: "text/x-perl",
 		extraKeys: {
 			"F1": function(cm) {
 				var selection = cm.getSelection();
@@ -66,6 +85,8 @@ function StartPedro(editorId) {
 			}
 		}
 	});
+	// Editor is by default Perl
+	changeMode(editor, 'perl');
 
 	// Pedro should be fullscreen
 	goFullScreen(editor);
